pub fn emit_span(span: ResourceSpan)Expand description
Emit one completed ResourceSpan to the process-wide exporter.
If no exporter has been installed this is a no-op; the caller’s operation must not depend on observability delivery.
pub fn emit_span(span: ResourceSpan)Emit one completed ResourceSpan to the process-wide exporter.
If no exporter has been installed this is a no-op; the caller’s operation must not depend on observability delivery.